.. _contact:

=======
Contact
=======

.. _mail list:

Mailing List
============

There is a mailing list for getting help and for discussing ASE:

* ase-users_

.. _ase-users: https://listserv.fysik.dtu.dk/mailman/listinfo/ase-users


Chat
====

Please join one of the ASE chats if you have any questions:

 * The ``#ase`` channel on Matrix_, also accessible via the Element_ webclient.

 * The ``#ase`` channel on the Freenode IRC (Internet Relay Chat) network,
   also accessible via Freenode_ webclient.

.. _Matrix: https://matrix.to/#/!JEiuNJLuxedbohAOuH:matrix.org
.. _Element: https://app.element.io/#/room/#ase:matrix.org
.. _Freenode: https://webchat.freenode.net/#ase?nick=Guest_?


Forum
=====

There is an `ASE forum <https://matsci.org/c/ase/36>`_ on the
`Materials Science Community Forum <https://matsci.org/>`_.


GitLab
======

Feel free to create Merge Requests and Issues on our GitLab page:
https://gitlab.com/ase/ase

For regular support, please use the mailing list or chat rather than GitLab.
